pub struct IrqRequest { /* private fields */ }Expand description
Request parameters for an IRQ action.
Implementations
Sourceimpl IrqRequest
impl IrqRequest
Sourcepub fn new(
handler: impl FnMut(IrqContext) -> IrqReturn + Send + 'static,
) -> Self
pub fn new( handler: impl FnMut(IrqContext) -> IrqReturn + Send + 'static, ) -> Self
Creates a new exclusive, global, auto-enabled IRQ request.
Sourcepub fn new_concurrent(
handler: impl Fn(IrqContext) -> IrqReturn + Send + Sync + 'static,
) -> Self
pub fn new_concurrent( handler: impl Fn(IrqContext) -> IrqReturn + Send + Sync + 'static, ) -> Self
Creates a new exclusive, global, auto-enabled concurrent IRQ request.
Sourcepub fn affinity(self, affinity: IrqAffinity) -> Self
pub fn affinity(self, affinity: IrqAffinity) -> Self
Sets the IRQ affinity.
Sourcepub fn execution(self, execution: IrqExecution) -> Self
pub fn execution(self, execution: IrqExecution) -> Self
Sets the action execution contract.
Sets the sharing mode.
Sourcepub fn auto_enable(self, auto_enable: AutoEnable) -> Self
pub fn auto_enable(self, auto_enable: AutoEnable) -> Self
Sets whether the action should be enabled after request.
Sourcepub const fn auto_enable_mode(&self) -> AutoEnable
pub const fn auto_enable_mode(&self) -> AutoEnable
Returns whether the action should be enabled after request.